@@ -1,3 +1,5 @@
+import os
+
 from django.core.files.storage import FileSystemStorage
 
 class BaseStorage(FileSystemStorage):
@@ -6,7 +8,8 @@ class BaseStorage(FileSystemStorage):
             return super(BaseStorage, self)._open(name, mode)
         except IOError:
             try:
-                self._get(name)
+                f = self._get(name)
+                self._write(f, name)
                 return super(BaseStorage, self)._open(name, mode)
             except Exception:
                 pass
@@ -16,3 +19,10 @@ class BaseStorage(FileSystemStorage):
         if super(BaseStorage, self).exists(name):
             return True
         return self._exists(name)
+
+    def _write(self, filelike, name):
+        dirname = os.path.dirname(self.path(name))
+        if not os.path.exists(dirname):
+            os.makedirs(dirname)
+        f = open(self.path(name), mode='wb')
+        f.write(filelike.read())
\ No newline at end of file
