@@ -15,9 +15,11 @@ class HttpStorage(BaseStorage):
 
     def _exists(self, name):
         request = urllib2.Request(self._path(name))
-        request.get_method = lambda : 'HEAD'
-        response = urllib2.urlopen(request)
-        return response.code == 200
+        try:
+            response = urllib2.urlopen(request)
+            return response.code == 200
+        except Exception:
+            return False
 
     def _path(self, name):
         return self.fallback_url + name
@@ -27,8 +29,4 @@ class HttpStorage(BaseStorage):
         response = urllib2.urlopen(request)
         if response.code != 200:
             raise IOError()
-        dirname = os.path.dirname(self.path(name))
-        if not os.path.exists(dirname):
-            os.makedirs(dirname)
-        f = open(self.path(name), mode='wb')
-        f.write(response.read())
\ No newline at end of file
+        return response
\ No newline at end of file
